// src/index.ts
import { ExpressiveCodeTheme, InlineStyleAnnotation } from "@expressive-code/core";

// src/cache.ts
import { getHighlighter } from "shiki";
var highlighterPromise;
async function getCachedHighlighter({ theme }) {
  if (highlighterPromise === void 0) {
    highlighterPromise = getHighlighter({ theme });
  }
  const highlighter = await highlighterPromise;
  if (!highlighter.getLoadedThemes().includes(theme.name)) {
    await highlighter.loadTheme(theme);
  }
  return highlighter;
}

// src/index.ts
import { BUNDLED_THEMES, loadTheme, FontStyle } from "shiki";
async function loadShikiTheme(bundledThemeName) {
  const shikiTheme = await loadTheme(BUNDLED_THEMES.includes(bundledThemeName) ? `themes/${bundledThemeName}.json` : bundledThemeName);
  const shikiThemeWithoutType = { ...shikiTheme };
  delete shikiThemeWithoutType.type;
  return new ExpressiveCodeTheme(shikiThemeWithoutType);
}
function pluginShiki() {
  return {
    name: "Shiki",
    hooks: {
      performSyntaxAnalysis: async ({ codeBlock, theme }) => {
        const highlighter = await getCachedHighlighter({ theme });
        const codeLines = codeBlock.getLines();
        const tokenLines = highlighter.codeToThemedTokens(codeBlock.code, codeBlock.language, theme.name);
        tokenLines.forEach((line, lineIndex) => {
          let charIndex = 0;
          line.forEach((token, tokenIndex) => {
            const tokenLength = token.content.length;
            const tokenEndIndex = charIndex + tokenLength;
            const lastTokenWasStringUnquotedArgument = tokenIndex > 0 && line[tokenIndex - 1]?.explanation?.slice(-1)[0]?.scopes?.some((scope) => scope.scopeName?.startsWith("string.unquoted.argument."));
            if (lastTokenWasStringUnquotedArgument) {
              const isCharBeforeRedirectOperator = tokenLength === 1 && token.content.trim().length === 1 && containsRedirectOperator(line[tokenIndex + 1]);
              const isCharAndRedirectOperator = tokenLength === 2 && token.content.trim().length === 2 && token.content[1] === ">" && containsRedirectOperator(token);
              if (isCharBeforeRedirectOperator || isCharAndRedirectOperator) {
                charIndex++;
                const lastAnnotation = codeLines[lineIndex].getAnnotations().slice(-1)[0];
                if (lastAnnotation && lastAnnotation.inlineRange) {
                  lastAnnotation.inlineRange.columnEnd = charIndex;
                }
                if (charIndex === tokenEndIndex)
                  return;
              }
            }
            const fontStyle = token.fontStyle || FontStyle.None;
            codeLines[lineIndex].addAnnotation(
              new InlineStyleAnnotation({
                color: token.color || theme.fg,
                italic: (fontStyle & FontStyle.Italic) === FontStyle.Italic,
                bold: (fontStyle & FontStyle.Bold) === FontStyle.Bold,
                underline: (fontStyle & FontStyle.Underline) === FontStyle.Underline,
                inlineRange: {
                  columnStart: charIndex,
                  columnEnd: tokenEndIndex
                }
              })
            );
            charIndex = tokenEndIndex;
          });
        });
      }
    }
  };
}
function containsRedirectOperator(token) {
  return token?.explanation?.some(
    (part) => (
      // Content must be a single ">"" character
      part.content === ">" && // Scope name must also indicate a redirect operator
      part.scopes?.some((scope) => scope.scopeName?.startsWith("keyword.operator.redirect."))
    )
  );
}
export {
  loadShikiTheme,
  pluginShiki
};
//# sourceMappingURL=index.js.map